<a id="2.10.0"></a>

## 2.10.0 - 2025-10-09

- Add a few more type checkers to top level tables by [@browniebroke](https://github.com/browniebroke) in
  [#$98](https://github.com/tox-dev/toml-fmt/pull/98)

<a id="2.9.0"></a>

## 2.9.0 - 2025-10-08

- Sort [tool.uv] higher in the pyproject.toml by [@browniebroke](https://github.com/browniebroke) in
  [#$97](https://github.com/tox-dev/toml-fmt/pull/97)

<a id="2.8.0"></a>

## 2.8.0 - 2025-10-08

- Fix parsing of version pre labels by [@adamchainz](https://github.com/adamchainz) in
  [#$89](https://github.com/tox-dev/toml-fmt/pull/89)

<a id="2.7.0"></a>

## 2.7.0 - 2025-10-01

- Macos 26 is not yet ready for wide usage by [@gaborbernat](https://github.com/gaborbernat) in
  [#$86](https://github.com/tox-dev/toml-fmt/pull/86)

<a id="2.6.0"></a>

## 2.6.0 - 2025-05-19

- Use abi3-py39 by [@gaborbernat](https://github.com/gaborbernat) in [#$58](https://github.com/tox-dev/toml-fmt/pull/58)

<a id="2.5.0"></a>

## 2.5.0 - 2024-10-30

- Add support for PEP 735 dependency-groups by [@browniebroke](https://github.com/browniebroke) in
  [#$16](https://github.com/tox-dev/toml-fmt/pull/16)

<a id="2.4.3"></a>

## 2.4.3 - 2024-10-17

- Fix tomli not present for Python<3.11 by [@gaborbernat](https://github.com/gaborbernat) in
  [#$9](https://github.com/tox-dev/toml-fmt/pull/9)

<a id="2.4.2"></a>

## 2.4.2 - 2024-10-17

- Fix release script by [@gaborbernat](https://github.com/gaborbernat)

<a id="2.4.1"></a>

## 2.4.1 - 2024-10-17

- Fix release script by [@gaborbernat](https://github.com/gaborbernat) in
  [#$8](https://github.com/tox-dev/toml-fmt/pull/8)

<a id="2.4.0"></a>

## 2.4.0 - 2024-10-17

- Fix GitHub action warning by [@gaborbernat](https://github.com/gaborbernat)

<a id="2.3.0"></a>

# [2.3.1](https://github.com/tox-dev/pyproject-fmt/releases/tag/2.3.1) - 2024-10-14

- Remove `tool.ruff.target_version` by [@edgarrmondragon](https://github.com/edgarrmondragon) in
  [#268](https://github.com/tox-dev/pyproject-fmt/pull/268)
- Pull in description fix by [@gaborbernat](https://github.com/gaborbernat) in
  [#272](https://github.com/tox-dev/pyproject-fmt/pull/272) thanks [@hugovk](https://github.com/hugovk)

<a id="2.3.0"></a>

# [2.3.0](https://github.com/tox-dev/pyproject-fmt/releases/tag/2.3.0) - 2024-10-10

- Drop 3.8 support and set 3.13 latest stable by [@gaborbernat](https://github.com/gaborbernat) in
  [#267](https://github.com/tox-dev/pyproject-fmt/pull/267)

<a id="2.2.4"></a>

# [2.2.4](https://github.com/tox-dev/pyproject-fmt/releases/tag/2.2.4) - 2024-09-17

- Improve the CI by [@gaborbernat](https://github.com/gaborbernat) in
  [#257](https://github.com/tox-dev/pyproject-fmt/pull/257)

<a id="2.2.3"></a>

# [2.2.3](https://github.com/tox-dev/pyproject-fmt/releases/tag/2.2.3) - 2024-09-08

- Fix declare 3.13 support by [@gaborbernat](https://github.com/gaborbernat) in
  [#253](https://github.com/tox-dev/pyproject-fmt/pull/253)

<a id="2.2.2"></a>

# [2.2.2](https://github.com/tox-dev/pyproject-fmt/releases/tag/2.2.2) - 2024-09-08

- Declare 3.13 support by [@gaborbernat](https://github.com/gaborbernat) in
  [#252](https://github.com/tox-dev/pyproject-fmt/pull/252)

<a id="2.2.1"></a>

# [2.2.1](https://github.com/tox-dev/pyproject-fmt/releases/tag/2.2.1) - 2024-07-31

- Pull in array split fix by [@gaborbernat](https://github.com/gaborbernat) in
  [#245](https://github.com/tox-dev/pyproject-fmt/pull/245)

CC [@flying-sheep](https://github.com/flying-sheep)

<a id="2.2.0"></a>

# [2.2.0](https://github.com/tox-dev/pyproject-fmt/releases/tag/2.2.0) - 2024-07-30

- Add Philosophy section by [@nathanjmcdougall](https://github.com/nathanjmcdougall) in
  [#235](https://github.com/tox-dev/pyproject-fmt/pull/235)
- Allow for reading TOML files from stdin. by [@fniessink](https://github.com/fniessink) in
  [#239](https://github.com/tox-dev/pyproject-fmt/pull/239)

<a id="2.1.4"></a>

# [2.1.4](https://github.com/tox-dev/pyproject-fmt/releases/tag/2.1.4) - 2024-07-03

- ci: try uv by [@henryiii](https://github.com/henryiii) in [#225](https://github.com/tox-dev/pyproject-fmt/pull/225)
- fix: new column width by [@henryiii](https://github.com/henryiii) in
  [#224](https://github.com/tox-dev/pyproject-fmt/pull/224)
- Fix sorting not using full spec by [@gaborbernat](https://github.com/gaborbernat) in
  [#232](https://github.com/tox-dev/pyproject-fmt/pull/232)

<a id="2.1.3"></a>

# [2.1.3](https://github.com/tox-dev/pyproject-fmt/releases/tag/2.1.3) - 2024-05-21

- Fix table expansion leaves behind extra content by [@gaborbernat](https://github.com/gaborbernat) in
  [#223](https://github.com/tox-dev/pyproject-fmt/pull/223)

<a id="2.1.2"></a>

# [2.1.2](https://github.com/tox-dev/pyproject-fmt/releases/tag/2.1.2) - 2024-05-20

- Pull in comments misplaced in tables fix by [@gaborbernat](https://github.com/gaborbernat) in
  [#221](https://github.com/tox-dev/pyproject-fmt/pull/221)

<a id="2.1.1"></a>

# [2.1.1](https://github.com/tox-dev/pyproject-fmt/releases/tag/2.1.1) - 2024-05-15

- Pull in empty sub-tables makes formatting unstable fix by [@gaborbernat](https://github.com/gaborbernat) in
  [#218](https://github.com/tox-dev/pyproject-fmt/pull/218)

<a id="2.1.0"></a>

# [2.1.0](https://github.com/tox-dev/pyproject-fmt/releases/tag/2.1.0) - 2024-05-14

- Add API by [@gaborbernat](https://github.com/gaborbernat) in [#216](https://github.com/tox-dev/pyproject-fmt/pull/216)
- Pull in fixes from upstream by [@gaborbernat](https://github.com/gaborbernat) in
  [#217](https://github.com/tox-dev/pyproject-fmt/pull/217)
  - Format the ruff table by [@gaborbernat](https://github.com/gaborbernat) in
    [#14](https://github.com/tox-dev/pyproject-fmt-rust/pull/14)
  - Ensure sorting is stable by [@gaborbernat](https://github.com/gaborbernat) in
    [#16](https://github.com/tox-dev/pyproject-fmt-rust/pull/16)
  - Do not delete array tables by [@gaborbernat](https://github.com/gaborbernat) in
    [#17](https://github.com/tox-dev/pyproject-fmt-rust/pull/17)

<a id="2.0.4"></a>

# [2.0.4](https://github.com/tox-dev/pyproject-fmt/releases/tag/2.0.4) - 2024-05-13

- Update README.md by [@gaborbernat](https://github.com/gaborbernat) in
  [#203](https://github.com/tox-dev/pyproject-fmt/pull/203)
- Remove outdated YAML example by [@hugovk](https://github.com/hugovk) in
  [#204](https://github.com/tox-dev/pyproject-fmt/pull/204)
- lost 'tomli' dependency when python_version < "3.11" by [@gassyfeve](https://github.com/gassyfeve) in
  [#209](https://github.com/tox-dev/pyproject-fmt/pull/209)
- Fix table ordering for sub tables and do not version strip on the ~ operator by
  [@gaborbernat](https://github.com/gaborbernat) in [#210](https://github.com/tox-dev/pyproject-fmt/pull/210)

<a id="2.0.3"></a>

# [2.0.3](https://github.com/tox-dev/pyproject-fmt/releases/tag/2.0.3) - 2024-05-11

- Pull in upstream fixes, see https://github.com/tox-dev/pyproject-fmt-rust/releases/tag/1.0.4 and update docs by
  [@gaborbernat](https://github.com/gaborbernat) in [#202](https://github.com/tox-dev/pyproject-fmt/pull/202)

<a id="2.0.2"></a>

# [2.0.2](https://github.com/tox-dev/pyproject-fmt/releases/tag/2.0.2) - 2024-05-11

- Pass configuration via separate class by [@gaborbernat](https://github.com/gaborbernat) in
  [#197](https://github.com/tox-dev/pyproject-fmt/pull/197)

<a id="2.0.1"></a>

# [2.0.1](https://github.com/tox-dev/pyproject-fmt/releases/tag/2.0.1) - 2024-05-11

- Fix missing dependency by [@gaborbernat](https://github.com/gaborbernat) in
  [#195](https://github.com/tox-dev/pyproject-fmt/pull/195)

<a id="2.0.0"></a>

# [2.0.0](https://github.com/tox-dev/pyproject-fmt/releases/tag/2.0.0) - 2024-05-10

- Migrate to version 2 powered by [pyproject-fmt-rust](https://github.com/tox-dev/pyproject-fmt-rust) by
  [@gaborbernat](https://github.com/gaborbernat) in [#194](https://github.com/tox-dev/pyproject-fmt/pull/194)

This introduces multiple changes:

- the requirements are formatted to be shorter and normalized
- the TOML is now formatted via https://taplo.tamasfe.dev/configuration/formatter-options.html
- will force arrays to be multiline (can use the column_width configuration to trigger this realign less aggressive)
- now supports min python version setting via cli/config
- normalizes project fields to use string instead of string literal
- collapses project sub tables to be inline within the project table
- comments are now attached to the next entry and moved alongside entries during re-ordering/sorting

<a id="1.8.0"></a>

# [1.8.0](https://github.com/tox-dev/pyproject-fmt/releases/tag/1.8.0) - 2024-04-17

- Enforce single line `description` by [@edgarrmondragon](https://github.com/edgarrmondragon) in
  [#184](https://github.com/tox-dev/pyproject-fmt/pull/184)

<a id="1.7.0"></a>

# [1.7.0](https://github.com/tox-dev/pyproject-fmt/releases/tag/1.7.0) - 2024-01-22

- Configure pyproject-fmt options from `pyproject.toml` file by [@edgarrmondragon](https://github.com/edgarrmondragon)
  in [#169](https://github.com/tox-dev/pyproject-fmt/pull/169)

<a id="1.6.0"></a>

# [1.6.0](https://github.com/tox-dev/pyproject-fmt/releases/tag/1.6.0) - 2024-01-10

- Support adding the classifier for the current Python prerelease by
  [@edgarrmondragon](https://github.com/edgarrmondragon) in [#162](https://github.com/tox-dev/pyproject-fmt/pull/162)
- Fix the "Release to PyPI" workflow and add check-jsonschema as a pre-commit hook to prevent future errors by
  [@edgarrmondragon](https://github.com/edgarrmondragon) in [#167](https://github.com/tox-dev/pyproject-fmt/pull/167)

<a id="1.5.3"></a>

# [1.5.3](https://github.com/tox-dev/pyproject-fmt/releases/tag/1.5.3) - 2023-12-02

- feat: Add `poetry-dynamic-versioning` build backend by [@edgarrmondragon](https://github.com/edgarrmondragon) in
  [#158](https://github.com/tox-dev/pyproject-fmt/pull/158)

<a id="1.5.2"></a>

# [1.5.2](https://github.com/tox-dev/pyproject-fmt/releases/tag/1.5.2) - 2023-11-29

- feat: Add `deptry` tool by [@edgarrmondragon](https://github.com/edgarrmondragon) in
  [#157](https://github.com/tox-dev/pyproject-fmt/pull/157)

<a id="1.5.1"></a>

# [1.5.1](https://github.com/tox-dev/pyproject-fmt/releases/tag/1.5.1) - 2023-11-09

<a id="1.5.0"></a>

# [1.5.0](https://github.com/tox-dev/pyproject-fmt/releases/tag/1.5.0) - 2023-11-09

- fix: add more tools by [@henryiii](https://github.com/henryiii) in
  [#154](https://github.com/tox-dev/pyproject-fmt/pull/154)

<a id="1.4.1"></a>

# [1.4.1](https://github.com/tox-dev/pyproject-fmt/releases/tag/1.4.1) - 2023-11-01

- Allow --check and --keep-full-version, they are not mutually exclusive by
  [@adamtheturtle](https://github.com/adamtheturtle) in [#152](https://github.com/tox-dev/pyproject-fmt/pull/152)

<a id="1.4.0"></a>

# [1.4.0](https://github.com/tox-dev/pyproject-fmt/releases/tag/1.4.0) - 2023-11-01

- Remove normalize_requires method by [@adamtheturtle](https://github.com/adamtheturtle) in
  [#142](https://github.com/tox-dev/pyproject-fmt/pull/142)
- Add test for normalize_pep508_array by [@adamtheturtle](https://github.com/adamtheturtle) in
  [#143](https://github.com/tox-dev/pyproject-fmt/pull/143)
- Add test for indent at formatter test level by [@adamtheturtle](https://github.com/adamtheturtle) in
  [#146](https://github.com/tox-dev/pyproject-fmt/pull/146)
- Test passing indent option at CLI level by [@adamtheturtle](https://github.com/adamtheturtle) in
  [#147](https://github.com/tox-dev/pyproject-fmt/pull/147)
- chore: modernize Ruff config by [@henryiii](https://github.com/henryiii) in
  [#148](https://github.com/tox-dev/pyproject-fmt/pull/148)
- fix: support more common tools by [@henryiii](https://github.com/henryiii) in
  [#149](https://github.com/tox-dev/pyproject-fmt/pull/149)
- Add option to skip normalizing requirement versions by [@adamtheturtle](https://github.com/adamtheturtle) in
  [#150](https://github.com/tox-dev/pyproject-fmt/pull/150)

<a id="1.3.0"></a>

# [1.3.0](https://github.com/tox-dev/pyproject-fmt/releases/tag/1.3.0) - 2023-10-25

- CLI: Accept `--version` argument, to print the package version by [@amotl](https://github.com/amotl) in
  [#139](https://github.com/tox-dev/pyproject-fmt/pull/139)
- Fix generating Python version classifiers based on python-requires by [@gaborbernat](https://github.com/gaborbernat)
  in [#140](https://github.com/tox-dev/pyproject-fmt/pull/140)

<a id="1.2.0"></a>

# [1.2.0](https://github.com/tox-dev/pyproject-fmt/releases/tag/1.2.0) - 2023-10-02

- GitHub Actions: Autoupgrade to Py3.12 production release by [@cclauss](https://github.com/cclauss) in
  [#131](https://github.com/tox-dev/pyproject-fmt/pull/131)
- \_PY_MAX_VERSION: int = 12 by [@cclauss](https://github.com/cclauss) in
  [#132](https://github.com/tox-dev/pyproject-fmt/pull/132)

<a id="1.1.0"></a>

# [1.1.0](https://github.com/tox-dev/pyproject-fmt/releases/tag/1.1.0) - 2023-08-28

- feat: allow pep440 version specifiers in requires-python by [@MindTooth](https://github.com/MindTooth) in
  [#123](https://github.com/tox-dev/pyproject-fmt/pull/123)

<a id="1.0.0"></a>

# [1.0.0](https://github.com/tox-dev/pyproject-fmt/releases/tag/1.0.0) - 2023-08-22

- Ignore failure of tox executable and drop 3.7 by [@gaborbernat](https://github.com/gaborbernat) in
  [#121](https://github.com/tox-dev/pyproject-fmt/pull/121)

<a id="0.13.1"></a>

# [0.13.1](https://github.com/tox-dev/pyproject-fmt/releases/tag/0.13.1) - 2023-08-11

- feat: include tox.ini in sdist by [@mj0nez](https://github.com/mj0nez) in
  [#116](https://github.com/tox-dev/pyproject-fmt/pull/116)

<a id="0.13.0"></a>

# [0.13.0](https://github.com/tox-dev/pyproject-fmt/releases/tag/0.13.0) - 2023-07-03

<a id="0.12.1"></a>

# [0.12.1](https://github.com/tox-dev/pyproject-fmt/releases/tag/0.12.1) - 2023-06-20

<a id="0.12.0"></a>

# [0.12.0](https://github.com/tox-dev/pyproject-fmt/releases/tag/0.12.0) - 2023-06-15

- git ls-files -z -- .github/workflows/check.yml | xargs -0 sed -i 's|3.12.0-alpha.7|3.12.0-beta.1|g' by
  [@gaborbernat](https://github.com/gaborbernat) in [#98](https://github.com/tox-dev/pyproject-fmt/pull/98)
- Add ruff by [@gaborbernat](https://github.com/gaborbernat) in
  [#100](https://github.com/tox-dev/pyproject-fmt/pull/100)

<a id="0.11.2"></a>

# [0.11.2](https://github.com/tox-dev/pyproject-fmt/releases/tag/0.11.2) - 2023-05-09

- Do not crash on out of order tables by [@gaborbernat](https://github.com/gaborbernat) in
  [#96](https://github.com/tox-dev/pyproject-fmt/pull/96)

<a id="0.11.1"></a>

# [0.11.1](https://github.com/tox-dev/pyproject-fmt/releases/tag/0.11.1) - 2023-04-28

- Keep implementation classifiers by [@gaborbernat](https://github.com/gaborbernat) in
  [#91](https://github.com/tox-dev/pyproject-fmt/pull/91)

<a id="0.11.0"></a>

# [0.11.0](https://github.com/tox-dev/pyproject-fmt/releases/tag/0.11.0) - 2023-04-28

- Add trusted-publish by [@gaborbernat](https://github.com/gaborbernat) in
  [#89](https://github.com/tox-dev/pyproject-fmt/pull/89)
- Generate python version classifiers based on python-requires by [@gaborbernat](https://github.com/gaborbernat) in
  [#90](https://github.com/tox-dev/pyproject-fmt/pull/90)

<a id="0.10.0"></a>

# [0.10.0](https://github.com/tox-dev/pyproject-fmt/releases/tag/0.10.0) - 2023-04-24

- Sort classifiers and respect `--indent` by [@hugovk](https://github.com/hugovk) in
  [#84](https://github.com/tox-dev/pyproject-fmt/pull/84)

<a id="0.9.2"></a>

# [0.9.2](https://github.com/tox-dev/pyproject-fmt/releases/tag/0.9.2) - 2023-02-27

- Fix unnecessary newline addition on sub-tables by [@adamchainz](https://github.com/adamchainz) in
  [#70](https://github.com/tox-dev/pyproject-fmt/pull/70)

<a id="0.9.1"></a>

# [0.9.1](https://github.com/tox-dev/pyproject-fmt/releases/tag/0.9.1) - 2023-02-14

- Put setuptools_scm after setuptools by [@gaborbernat](https://github.com/gaborbernat) in
  [#68](https://github.com/tox-dev/pyproject-fmt/pull/68)

<a id="0.9.0"></a>

# [0.9.0](https://github.com/tox-dev/pyproject-fmt/releases/tag/0.9.0) - 2023-02-14

- Add tools ordering and separate tables by one line by [@gaborbernat](https://github.com/gaborbernat) in
  [#67](https://github.com/tox-dev/pyproject-fmt/pull/67)

<a id="0.8.0"></a>

# [0.8.0](https://github.com/tox-dev/pyproject-fmt/releases/tag/0.8.0) - 2023-02-09

- Follow the package name normalization spec by [@hugovk](https://github.com/hugovk) in
  [#66](https://github.com/tox-dev/pyproject-fmt/pull/66)

<a id="0.7.0"></a>

# [0.7.0](https://github.com/tox-dev/pyproject-fmt/releases/tag/0.7.0) - 2023-02-07

- add pre-commit snippet to readme by [@RonnyPfannschmidt](https://github.com/RonnyPfannschmidt) in
  [#62](https://github.com/tox-dev/pyproject-fmt/pull/62)
- Bump deps and tools by [@gaborbernat](https://github.com/gaborbernat) in
  [#63](https://github.com/tox-dev/pyproject-fmt/pull/63)
- add --check by [@bollwyvl](https://github.com/bollwyvl) in [#65](https://github.com/tox-dev/pyproject-fmt/pull/65)

- [@RonnyPfannschmidt](https://github.com/RonnyPfannschmidt) made their first contribution in
  [#62](https://github.com/tox-dev/pyproject-fmt/pull/62)
- [@bollwyvl](https://github.com/bollwyvl) made their first contribution in
  [#65](https://github.com/tox-dev/pyproject-fmt/pull/65)

<a id="0.6.0"></a>

# [0.6.0](https://github.com/tox-dev/pyproject-fmt/releases/tag/0.6.0) - 2023-01-30

- Handle inline tables and change order, so dependencies and optional-dependencies are closer to each other.

<a id="0.5.0"></a>

# [0.5.0](https://github.com/tox-dev/pyproject-fmt/releases/tag/0.5.0) - 2023-01-19

- Update version of `pyproject-fmt` in example pre-commit hook in docs by [@namurphy](https://github.com/namurphy) in
  [#58](https://github.com/tox-dev/pyproject-fmt/pull/58)
- Exclude bots from generated release notes by [@hugovk](https://github.com/hugovk) in
  [#61](https://github.com/tox-dev/pyproject-fmt/pull/61)
- Only write to file if changed by [@hugovk](https://github.com/hugovk) in
  [#60](https://github.com/tox-dev/pyproject-fmt/pull/60)

<a id="0.4.1"></a>

# [0.4.1](https://github.com/tox-dev/pyproject-fmt/releases/tag/0.4.1) - 2022-11-23

- Programming Language :: Python :: 3.11 by [@cclauss](https://github.com/cclauss) in
  [#47](https://github.com/tox-dev/pyproject-fmt/pull/47)

<a id="0.4.0"></a>

# [0.4.0](https://github.com/tox-dev/pyproject-fmt/releases/tag/0.4.0) - 2022-11-23

- [pre-commit.ci] pre-commit autoupdate by [@pre-commit-ci](https://github.com/pre-commit-ci) in
  [#38](https://github.com/tox-dev/pyproject-fmt/pull/38)
- [pre-commit.ci] pre-commit autoupdate by [@pre-commit-ci](https://github.com/pre-commit-ci) in
  [#39](https://github.com/tox-dev/pyproject-fmt/pull/39)
- [pre-commit.ci] pre-commit autoupdate by [@pre-commit-ci](https://github.com/pre-commit-ci) in
  [#41](https://github.com/tox-dev/pyproject-fmt/pull/41)
- [pre-commit.ci] pre-commit autoupdate by [@pre-commit-ci](https://github.com/pre-commit-ci) in
  [#42](https://github.com/tox-dev/pyproject-fmt/pull/42)
- [pre-commit.ci] pre-commit autoupdate by [@pre-commit-ci](https://github.com/pre-commit-ci) in
  [#43](https://github.com/tox-dev/pyproject-fmt/pull/43)
- [pre-commit.ci] pre-commit autoupdate by [@pre-commit-ci](https://github.com/pre-commit-ci) in
  [#44](https://github.com/tox-dev/pyproject-fmt/pull/44)
- feat: support multiple "pyproject.toml" files by [@KyleKing](https://github.com/KyleKing) in
  [#46](https://github.com/tox-dev/pyproject-fmt/pull/46)

<a id="0.3.5"></a>

# [0.3.5](https://github.com/tox-dev/pyproject-fmt/releases/tag/0.3.5) - 2022-08-13

- [pre-commit.ci] pre-commit autoupdate by [@pre-commit-ci](https://github.com/pre-commit-ci) in
  [#28](https://github.com/tox-dev/pyproject-fmt/pull/28)
- [pre-commit.ci] pre-commit autoupdate by [@pre-commit-ci](https://github.com/pre-commit-ci) in
  [#29](https://github.com/tox-dev/pyproject-fmt/pull/29)
- Support tomlkit 0.11 by [@gaborbernat](https://github.com/gaborbernat) in
  [#33](https://github.com/tox-dev/pyproject-fmt/pull/33)
- Bump actions/checkout from 2 to 3 by [@dependabot](https://github.com/dependabot) in
  [#35](https://github.com/tox-dev/pyproject-fmt/pull/35)
- Bump actions/setup-python from 2 to 4 by [@dependabot](https://github.com/dependabot) in
  [#34](https://github.com/tox-dev/pyproject-fmt/pull/34)

<a id="0.3.4"></a>

# [Fix project links (0.3.4)](https://github.com/tox-dev/pyproject-fmt/releases/tag/0.3.4) - 2022-06-26

- [pre-commit.ci] pre-commit autoupdate by [@pre-commit-ci](https://github.com/pre-commit-ci) in
  [#19](https://github.com/tox-dev/pyproject-fmt/pull/19)
- [pre-commit.ci] pre-commit autoupdate by [@pre-commit-ci](https://github.com/pre-commit-ci) in
  [#20](https://github.com/tox-dev/pyproject-fmt/pull/20)
- [pre-commit.ci] pre-commit autoupdate by [@pre-commit-ci](https://github.com/pre-commit-ci) in
  [#21](https://github.com/tox-dev/pyproject-fmt/pull/21)
- [pre-commit.ci] pre-commit autoupdate by [@pre-commit-ci](https://github.com/pre-commit-ci) in
  [#24](https://github.com/tox-dev/pyproject-fmt/pull/24)
- [pre-commit.ci] pre-commit autoupdate by [@pre-commit-ci](https://github.com/pre-commit-ci) in
  [#25](https://github.com/tox-dev/pyproject-fmt/pull/25)

<a id="0.3.3"></a>

# [Fix help message referring to tox.ini files (0.3.3)](https://github.com/tox-dev/pyproject-fmt/releases/tag/0.3.3) - 2022-03-23

<a id="0.3.2"></a>

# [0.3.2](https://github.com/tox-dev/pyproject-fmt/releases/tag/0.3.2) - 2022-03-01

<a id="0.3.1"></a>

# [0.3.1](https://github.com/tox-dev/pyproject-fmt/releases/tag/0.3.1) - 2022-02-27

<a id="0.3.0"></a>

# [0.3.0](https://github.com/tox-dev/pyproject-fmt/releases/tag/0.3.0) - 2022-02-27

<a id="0.2.0"></a>

# [Support build-system (0.2.0)](https://github.com/tox-dev/pyproject-fmt/releases/tag/0.2.0) - 2022-02-21

<a id="0.1.0"></a>

# [Base version (0.1.0)](https://github.com/tox-dev/pyproject-fmt/releases/tag/0.1.0) - 2022-02-21

<!-- Generated by https://github.com/rhysd/changelog-from-release v3.8.0 -->
